﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.DragDrop;
using System.Collections;
using Telerik.Windows.Controls;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace _289660_GridViewToCheckBoxesDnD
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();

			this.radGridView.ItemsSource = GenerateProducts();
			this.myListBox.ItemsSource = GenerateItems();

			RadDragAndDropManager.AddDragQueryHandler(radGridView, OnGridViewDragQuery);
			RadDragAndDropManager.AddDragInfoHandler(radGridView, OnGridViewDragInfo);

			RadDragAndDropManager.AddDropQueryHandler(myListBox, ListBox_OnDropQuery);
			RadDragAndDropManager.AddDropInfoHandler(myListBox, ListBox_OnDropInfo);

		}

		
		#region Data Collection

		public class ProductViewModel
		{
			public string Name { get; set; }
			public string Description { get; set; }
			public decimal UnitPrice { get; set; }
			public string ImageSrc { get; set; }
		}

		public class ListBoxData
		{
			public string Name { get; set; }
			public string ImageSrc { get; set; }
		}

		private ObservableCollection<ProductViewModel> GenerateProducts()
		{
			ObservableCollection<ProductViewModel> result = new ObservableCollection<ProductViewModel>();
			for (int i = 1; i < 20; i++)
			{
				ProductViewModel product = new ProductViewModel()
				{
					Name = String.Format("Name {0}", i),
					Description = String.Format("Description {0}", i),
					UnitPrice = i * 100,
					ImageSrc = "images/YellowIcon.png"
				};
				result.Add(product);
			}
			return result;
		}

		private ObservableCollection<ListBoxData> GenerateItems()
		{
			ObservableCollection<ListBoxData> result = new ObservableCollection<ListBoxData>();

			for (int i = 0; i < 10; i++)
			{
				ListBoxData item = new ListBoxData()
				{
					Name = String.Format("Name {0}", i),
					ImageSrc = "images/RedIcon.png"
				};
				result.Add(item);
			}
			return result;
		}

		#endregion

		#region DragDropEvent handlers

		//DragQuery event handler 
		private void OnGridViewDragQuery(object sender, DragDropQueryEventArgs e)
		{
			RadGridView gridView = sender as RadGridView;
			if (gridView != null)
			{
				e.Options.Payload = gridView.SelectedItem;
			}
			e.QueryResult = true;
			e.Handled = true;
		}

		//DragInfo event handler
		private void OnGridViewDragInfo(object sender, DragDropEventArgs e)
		{
			RadGridView gridView = sender as RadGridView;
			ProductViewModel draggedItem = e.Options.Payload as ProductViewModel;

			if (e.Options.Status == DragStatus.DragInProgress)
			{
				//Setting up a drag cue:
				ContentControl cue = new ContentControl();
				//Choosing a template for the items:
				cue.ContentTemplate = this.Resources["CueTemplate"] as DataTemplate;
				cue.Content = draggedItem;
				e.Options.DragCue = cue;

			}
			else if (e.Options.Status == DragStatus.DragComplete)
			{
				//deleting the dragged item from the RadGridView
				IList source = gridView.ItemsSource as IList;
				source.Remove(draggedItem);
			}
		}

		//DropQuery event handler 
		private void ListBox_OnDropQuery(object sender, DragDropQueryEventArgs e)
		{
			System.Windows.Controls.ListBox destination = sender as System.Windows.Controls.ListBox;

			if (destination != null)
			{
				e.Handled = true;
				e.QueryResult = true;
			}
		}

		//DropInfo event handler 
		private void ListBox_OnDropInfo(object sender, DragDropEventArgs e)
		{
			System.Windows.Controls.ListBox destination = sender as System.Windows.Controls.ListBox;

			ProductViewModel draggedItem = e.Options.Payload as ProductViewModel;
			ListBoxData droppedItem = new ListBoxData();
			droppedItem.Name = draggedItem.Name;
			droppedItem.ImageSrc = draggedItem.ImageSrc;

			if (e.Options.Status == DragStatus.DropComplete)
			{
				(destination.ItemsSource as IList<ListBoxData>).Add(droppedItem);
			}
		}

		#endregion

	}
}
